<?php
// wcf imports
require_once(WCF_DIR.'lib/action/AbstractAction.class.php');

/**
 * CustomPage Export Action
 * 
 * @author	 Martin Schwendowius
 * @copyright	2008-2009 plugins.wbuilder.de
 * @license	Creative Commons <http://creativecommons.org/licenses/by-nc-nd/3.0/deed.de>
 * @package	com.woltlab.community.customPage
 */
class CustomPageExportAction extends AbstractAction {
	public $pageInformations=array();
	public $wrappers=array();
	public $xmlContent;
	public $xmlPath;
	public $fileName;

	/**
	 * @see Action::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		//select available pages
		$sql = "SELECT * FROM wcf".WCF_N."_custompage";
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
			$this->pageInformations[] = $row;
		}
	}

	protected function generateXML() {
		//XML Version tag and leading tag
		$string = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n";
		$string .= "<customPages>\n";
    
		//pageInformations
		if (count($this->pageInformations)) {
			foreach($this->pageInformations as $key => $page) {
				$string .= "\t<page>\n";
				$string .= "\t\t<pageID><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['pageID']) : $page['pageID']))."]]></pageID>\n";
				$string .= "\t\t<name><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['name']) : $page['name']))."]]></name>\n";
				$string .= "\t\t<description><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['description']) : $page['description']))."]]></description>\n";        
				$string .= "\t\t<icon><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['icon']) : $page['icon']))."]]></icon>\n";
				$string .= "\t\t<wrapperID><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['wrapperID']) : $page['wrapperID']))."]]></wrapperID>\n";
				$string .= "\t\t<content><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['content']) : $page['content']))."]]></content>\n";
				$string .= "\t\t<parentPageID><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['parentPageID']) : $page['parentPageID']))."]]></parentPageID>\n";
				$string .= "\t\t<preParentID><![CDATA[".StringUtil::escapeCDATA((CHARSET != 'UTF-8' ? StringUtil::convertEncoding(CHARSET, 'UTF-8', $page['preParentID']) : $page['preParentID']))."]]></preParentID>\n";				
				$string .= "\t</page>\n";
			}
		}
		//ending tag
		$string .= "</customPages>";
		
		$this->xmlContent = $string;
		
		require_once(WCF_DIR.'lib/system/io/File.class.php');
		$xml = new File(WCF_DIR.'/lib/data/custompage/tmp/customPagesData.xml');
		$xml->write($this->xmlContent);
		$xml->close();
	} 
	
	protected function getPath() {
		// get xml path
		if (count($this->pageInformations)) {
			$xmlPath = WCF_DIR.'lib/data/custompage/tmp/customPagesData.xml';
		}	
		$this->xmlPath = $xmlPath;
	}

	/**
	 * generates g-zipped tarball of the pages XML file
	 */
	protected function generateTar() {

		if (!count($this->pageInformations)) {
		// breaks export action and redirects to list page if no pages found
		header('Location: index.php?page=CustomPageList&noPagesToExport=1&packageID='.PACKAGE_ID.SID_ARG_2ND_NOT_ENCODED);
		exit;
		} 
		$this->generateXML();
		$path = $this->getPath();
		$this->filename = WCF_DIR.'/lib/data/custompage/tmp/CustomPageExport.'.StringUtil::getRandomID().'.tgz';
		// generate gZipped export file 
		require_once(WCF_DIR.'lib/system/io/TarWriter.class.php');
		$tar = new TarWriter($this->filename, true);
		// add file
 		$tar->add($this->xmlPath, '', WCF_DIR.'lib/data/custompage/tmp/');
 		// create archive
 		$tar->create();
 		// unlink temp xml file
 		@unlink($this->xmlPath);
	} 
	
	/**
	 * @see Action::execute()
	 */
	public function execute() {
		parent::execute();
		// check permission
		WCFACP::checkMasterPassword();
		WCF::getUser()->checkPermission('admin.system.custompages.canExport');
		// starts generating export file
		$this->generateTar();	
		$this->executed();
		// headers for downloading file
		header('Content-Type: application/x-gzip; charset='.CHARSET);
		header('Content-Disposition: attachment; filename="CustomPageImport.tgz"');
		readfile($this->filename);
		// delete temp file
		@unlink($this->filename);
	}
}
?>