<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');
require_once(WCF_DIR.'lib/data/custompage/CustomPageEditor.class.php');

/**
 * Shows the CustomPage add form.
 *
 * @author	 Martin Schwendowius, Oliver Kliebisch
 * @copyright	2008-2009 plugins.wbuilder.de
 * @license	Creative Commons <hhttp://creativecommons.org/licenses/by-nc-nd/3.0/deed.de>
 * @package	com.woltlab.wbb.acp.form
 */
class CustomPageAddForm extends ACPForm {
	public $activeMenuItem = 'wcf.acp.menu.link.content.custompage.add';
	public $pageID;
	public $wrapperID;
	public $name;
	public $description;
	public $template;
	public $icon;
	public $permission;
	public $content;
	public $menuItemID;
	public $parentPageID;
	public $preParentID;
	public $itemSelect = array();
	public $wrappers = array();
	public $pages = array();
	public $templateName = 'customPageAdd';

	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		//select available wrappers
		$sql = "SELECT * FROM wcf".WCF_N."_custompage_wrapper";
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
			$this->wrappers[] = $row;
		}
		//select available pages
		$sql = "SELECT pageID, name, parentPageID FROM wcf".WCF_N."_custompage";
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
			$this->pages[] = array('pageID' => $row['pageID'], 'parentPageID' => $row['parentPageID'],
									'pageName' => $row['name']);
		}

		$this->createItemSelect();
	}
	
	/**
	 * Prepares the select data
	 */
	public function createItemSelect() {
		if(!count($this->pages)) return;
		
		$sortedPages = array();
		foreach($this->pages as $page) {
			if (!isset($sortedPages[$page['parentPageID']])) $sortedPages[$page['parentPageID']] = array();
			$sortedPages[$page['parentPageID']][] = $page;
		}
		$this->pages = $sortedPages;
		$this->makeItemSelect();
	}

	/**
	 * Creates the select items
	 *
	 * @param $parentPageID
	 * @param $depth
	 */
	public function makeItemSelect($parentPageID = 0, $depth = 0) {
		foreach($this->pages[$parentPageID] as $item) {
			if ($this->pageID !== null && $item['pageID'] == $this->pageID) continue;
			$title = WCF::getLanguage()->get(StringUtil::encodeHTML($item['pageName']));
			if ($depth > 0) $title = str_repeat('&nbsp;&nbsp;&nbsp;&nbsp;', $depth). ' ' . $title;
			$this->itemSelect[$item['pageID']] = $title;
			if(isset($this->pages[$item['pageID']])) {
				$this->makeItemSelect($item['pageID'], $depth+1);
			}
		}
	}

 /**
         * @see Form::readFormParameters()
         */
        public function readFormParameters() {
                parent::readFormParameters();

                if(isset($_REQUEST['name'])) $this->name = StringUtil::trim($_REQUEST['name']);
                if(isset($_REQUEST['description'])) $this->description = StringUtil::trim($_REQUEST['description']);
                if(isset($_REQUEST['icon'])) $this->icon = StringUtil::trim($_REQUEST['icon']);
                if(isset($_REQUEST['content'])) $this->content = StringUtil::trim($_REQUEST['content']);
                if(isset($_REQUEST['parentPageID'])) $this->parentPageID = intval($_REQUEST['parentPageID']);
                if(isset($_REQUEST['preParentID'])) $this->preParentID = intval($_REQUEST['preParentID']);
                if(isset($_REQUEST['wrapperID'])) $this->wrapperID = intval($_REQUEST['wrapperID']);
        }

	/**
	 * @see Form::validate()
	 */
	public function validate() {
		parent::validate();
		// wrapperID
		if (empty($this->wrapperID)) {
			throw new UserInputException('wrapperID');
		}
		// name
		if (empty($this->name)) {
			throw new UserInputException('name');
		}
		// icon
		if (empty($this->icon)) {
			throw new UserInputException('icon');
		}
		//content
		if (empty($this->content)) {
			throw new UserInputException('content');
		}
	}

	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		WCF::getTPL()->assign(array('wrappers' => $this->wrappers,
							'pages' => $this->pages,
							'name' => $this->name,
							'description' => $this->description,
							'icon' => $this->icon,
							'content' => $this->content,
							'pageID' => $this->pageID,
							'wrapperID' => $this->wrapperID,
							'parentPageID' => $this->parentPageID,
							'preParentID' => $this->preParentID,
							'itemSelect' => $this->itemSelect,
							'action' => 'add'));
		// sets active menuItem
		WCFACP::getMenu()->setActiveMenuItem($this->activeMenuItem);
	}

	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		$page = new CustomPageEditor();
		$page->create($this->name, $this->description, $this->icon, $this->wrapperID, $this->content, $this->parentPageID, $this->preParentID);
		$this->saved();
		//redirects to list page after save method
		header('Location: index.php?page=CustomPageList&addedPage=1&packageID='.PACKAGE_ID.SID_ARG_2ND_NOT_ENCODED);
		exit;
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		WCFACP::checkMasterPassword();
		
		parent::show();
	}
}
?>
