<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');

/**
 * CustomPage Export Action
 * 
 * @author	 Martin Schwendowius
 * @copyright	2008-2009 plugins.wbuilder.de
 * @license	Creative Commons <http://creativecommons.org/licenses/by-nc-nd/3.0/deed.de>
 * @package	com.woltlab.community.customPage
 */
class CustomPageImportForm extends ACPForm {
	public $templateName = 'customPageImport';
	public $activeMenuItem = 'wcf.acp.menu.link.content.custompage.import';
	
	public $fileUpload = '';
	public $data;
	public $fileData = array();
	public $filename = '';
	
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['filename'])) $this->filename = StringUtil::trim($_POST['filename']);
		if (isset($_FILES['fileUpload'])) $this->fileUpload = $_FILES['fileUpload'];
	}
	
	
	/**
	 * Reads the page informations from the importXML file
	 */
	protected static function readPageData($tar) {
		// check archive for required XML file
		$xml = 'customPagesData.xml';
		$i = $tar->getIndexByFilename($xml);
		if ($i === false) {
			throw new SystemException("Unable to find required file '".$xml."' in CustomPages import archive");
		}
		// open xml
		$pageXML = new XML();
		$pageXML->loadString($tar->extractToString($i));
		$xmlContent = $pageXML->getElementTree('customPages');
		$data = array();
		$i = 0;
		foreach ($xmlContent['children'] as $child) {
			if (!isset($data[$i])) $data[$i] = array();
			switch ($child['name']) {
				case 'page': 					
					foreach ($child['children'] as $page) {												 						
						switch ($page['name']) {
								case 'pageID': case 'name': case 'description': case 'icon': case 'wrapperID': 
								case 'content': case 'parentPageID': case 'preParentID': $data[$i][$page['name']] = $page['cdata']; break;
						}						
					}
					break;
			}
			$i++;
		}
		return $data;
	}
	
	/**
	 * Get data from import archive
	 */
	public static function getPageData($fileUpload) {
		// opens .tgz file
		require_once(WCF_DIR.'lib/system/io/Tar.class.php');
		$tar = new Tar($fileUpload);
		// gets pages data
		$data = self::readPageData($tar);		
		$tar->close();		
		return $data;
	}
	
	/**
	 * @see Form::validate()
	 */
	public function validate() {
		parent::validate();
		
		if (empty($this->fileUpload)) {
			throw new UserInputException('fileUpload');
		}
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		if(empty($this->fileUpload['tmp_name'])) return;
		$data = self::getPageData($this->fileUpload['tmp_name']);
		require_once(WCF_DIR.'lib/data/custompage/CustomPageEditor.class.php');
		CustomPageEditor::deleteAllCustomPages();
		foreach($data as $pageData) {
			$page = new CustomPageEditor();
			$page->importPages($pageData['pageID'], $pageData['name'], $pageData['description'], $pageData['icon'], $pageData['wrapperID'], $pageData['content'], $pageData['parentPageID'], $pageData['preParentID']);
		}
		$this->saved();
		//redirect to list page after save
		header('Location: index.php?page=CustomPageList&packageID='.PACKAGE_ID.SID_ARG_2ND_NOT_ENCODED);
		exit;
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		WCFACP::checkMasterPassword();
		
		parent::show();
	}
	
}
?>