<?php
// wcf imports
require_once(WCF_DIR.'/lib/page/AbstractPage.class.php');
require_once(WCF_DIR.'/lib/data/custompage/CustomPageEditor.class.php');

/**
 * Shows the CustomPage list page.
 * 
 * @author	 Martin Schwendowius, Oliver Kliebisch
 * @copyright	2008-2009 plugins.wbuilder.de
 * @license	Creative Commons <hhttp://creativecommons.org/licenses/by-nc-nd/3.0/deed.de>
 * @package	com.woltlab.community.customPage
 */
class CustomPageListPage extends AbstractPage {
        public $activeMenuItem = 'wcf.acp.menu.link.content.custompage.list';
        public $templateName = 'customPageList';
        public $pages;
        public $pageStructure;
	private $deletedPage = 0;
	private $addedPage = 0;
	private $editPage = 0;	
	private $deletedPages = 0;
	private $noWrapper = 0;
	private $noPagesToExport = 0;
	private $pagesExported = 0;
        
	/**
	 * @see Page::readParameters()
	 */	
	public function readParameters() {
		parent::readParameters();
		if (isset($_REQUEST['deletedPage'])) {
			$this->deletedPage = intval($_REQUEST['deletedPage']);
		}
		if (isset($_REQUEST['addedPage'])) {
			$this->addedPage = intval($_REQUEST['addedPage']);
		}
		if (isset($_REQUEST['editPage'])) {
			$this->editPage = intval($_REQUEST['editPage']);
		}
		if (isset($_REQUEST['deletedPages'])) {
			$this->deletedPages = intval($_REQUEST['deletedPages']);
		}
		if (isset($_REQUEST['noPagesToExport'])) {
			$this->noPagesToExport = intval($_REQUEST['noPagesToExport']);
		}

	}        

	/**
	 * @see Page::readData()
	 */	
        public function readData() {
                parent::readData();
		$this->renderPageStructure();
        }

	/**
	 * renders the page structure
	 */	
 	public function renderPageStructure() {
                $this->pages = CustomPageEditor::getPages();
                $sortedPages = array();

                foreach($this->pages as $page) {
                        if (!isset($sortedPages[$page->parentPageID])) $sortedPages[$page->parentPageID] = array(); 
                        $sortedPages[$page->parentPageID][] = $page;
                }
                $this->pages = $sortedPages;                
                
                $this->createPageStructure();
        }
        
	/**
	 * creates the recursive page structure
	 */	
        public function createPageStructure($parentPageID=0, $depth=0, $openParents=0) {
                
                if(!isset($this->pages[$parentPageID])) return;
                
                $i=0; $children = count($this->pages[$parentPageID]);
                $items = $this->pages[$parentPageID];                
                foreach($items as $item) {
                        $childrenOpenParents = $openParents + 1;
                        $hasChildren = isset($this->pages[$item->pageID]) ? count($this->pages[$item->pageID]) : 0;
                        $last = $i == count($this->pages[$parentPageID]) - 1;
                        if ($hasChildren && !$last) $childrenOpenParents = 1;
                        $this->pageStructure[] = array('depth' => $depth, 'hasChildren' => $hasChildren, 'openParents' => ((!$hasChildren && $last) ? ($openParents) : (0)), 'item' => $item, 'parentPageID' => $parentPageID, 'position' => $i+1, 'maxPosition' => $children);
                        
                        $this->createPageStructure($item->pageID, $depth + 1, $childrenOpenParents);
                        
                        $i++;
                }
                                
        }
        
	/**
	 * @see Page::assignVariables()
	 */	
        public function assignVariables() {
		      parent::assignVariables();
        
		WCF::getTPL()->assign(array('items' => $this->pageStructure,
			'deletedPage' => $this->deletedPage,
			'addedPage' => $this->addedPage,
			'editPage' => $this->editPage,
			'deletedPages' => $this->deletedPages,
			'noPagesToExport' => $this->noPagesToExport,
			'pagesExported' => $this->pagesExported,
			'noWrapper' => $this->noWrapper));
		// get active menuItem
  		WCFACP::getMenu()->setActiveMenuItem($this->activeMenuItem);
        }
}
?>