<?php
//wcf imports
require_once(WCF_DIR.'lib/system/language/LanguageEditor.class.php');

/**
 * CustomPage Editor Class
 * 
 * @author	 Martin Schwendowius, Oliver Kliebisch
 * @copyright	2008-2009 plugins.wbuilder.de
 * @license	Creative Commons <http://creativecommons.org/licenses/by-nc-nd/3.0/deed.de>
 * @package	com.woltlab.community.customPage
 */
class CustomPageEditor extends DatabaseObject {
	public $packageIdentifier = 'com.woltlab.community.customPage';
	public $packageID = 0;	
	public $pages = array();
	public $optionIDs = array();
	protected static $languageObjects = array();
	public $customPageMenuItem = null;

	/**
	 * Creates a new CustomPageEditor object.
	 */
	public function __construct($pageID=0, $row=null) {
		$sql="SELECT packageID FROM wcf".WCF_N."_package WHERE package='".$this->packageIdentifier."'";
		$result = WCF::getDB()->getFirstRow($sql);
		$this->packageID = $result['packageID'];		

		if($row == null && $pageID > 0) {
			$sql = "SELECT * FROM wcf".WCF_N."_custompage WHERE pageID=".$pageID;
			$row=WCF::getDB()->getFirstRow($sql);
		}
		if($pageID > 0 || $row !=null) $this->handleData($row);
		WCF::getCache()->addResource('custompages',
		WCF_DIR.'cache/cache.custompages.php',
		WCF_DIR.'lib/system/cache/CacheBuilderCustomPages.class.php');
	}


	public function __set($name, $value) {
		$this->data[$name] = $value;
	}
	
	/**
	 * Creates a page.
	 *
	 * @param	string		$name
	 * @param	string		$description
	 * @param	string		$icon
	 * @param	integer		$wrapperID
	 * @param	string		$content
	 * @param	integer		$parentPageID
	 * @param	integer		$preParentID
	 */
	public function create($name, $description, $icon, $wrapperID=1, $content, $parentPageID=0, $preParentID=0) {

		$this->name = $name;
		$this->description = $description;
		$this->icon = $icon;
		$this->wrapperID = $wrapperID;
		$this->content = $content;
		$this->parentPageID = $parentPageID;
		$this->preParentID = $preParentID;
		$sql = "INSERT INTO wcf".WCF_N."_custompage (name, description, icon, wrapperID, content, parentPageID, preParentID)
						VALUES ('".escapeString($name)."', '".escapeString($description)."', '".escapeString($icon)."', ".$wrapperID.", '".escapeString($content)."', 
								".$parentPageID.", ".$parentPageID.")";
		WCF::getDB()->sendQuery($sql);
		$this->pageID = WCF::getDB()->getInsertID();
		$this->generateTemplate();
		$this->generatePermission();
		if($parentPageID==0) $this->generateHeaderMenuItem();

		$sql = "UPDATE wcf".WCF_N."_custompage SET permission='".$this->permission."', menuItemID=".intval($this->menuItemID).", templateName='".$this->templateName."' WHERE pageID=".$this->pageID;
		WCF::getDB()->sendQuery($sql);
		$this->generatePageLocation();
		$this->clearCaches();
	}
	/**
	 * Updates a page.
	 * 
	 * @param	string		$name
	 * @param	string		$description
	 * @param	string		$icon
	 * @param	integer		$wrapperID
	 * @param	string		$content
	 * @param	integer		$parentPageID
	 * @param	integer		$preParentID
	 */
	public function update($name, $description, $icon, $wrapperID=1, $content, $parentPageID=0, $preParentID=0) {

		$this->name = $name;
		$this->description = $description;
		$this->icon = $icon;
		$this->wrapperID = $wrapperID;
		$this->content = $content;
		$this->parentPageID = $parentPageID;
		$this->preParentID = $preParentID;
		$sql = "UPDATE wcf".WCF_N."_custompage SET name='".escapeString($name)."', description= '".escapeString($description)."', icon= '".escapeString($icon)."', wrapperID= ".$wrapperID.", content= '".escapeString($content)."', parentPageID= ".$parentPageID.", preParentID= ".$preParentID." WHERE pageID = ".$this->pageID;
		WCF::getDB()->sendQuery($sql);
				
		if($preParentID != $parentPageID) {
			$this->deletePermissions($this->pageID);
			$this->deleteLanguageItems($this->pageID);
			$this->deleteHeaderMenuItem($this->pageID);
			$this->generatePermission();
			$sql = "UPDATE wcf".WCF_N."_custompage SET permission='".$this->permission."' WHERE pageID=".$this->pageID;
			WCF::getDB()->sendQuery($sql);
		}
				
		if($parentPageID == 0 && $preParentID != 0) {
			$this->deletePermissions($this->pageID);
			$this->deleteLanguageItems($this->pageID);
			$this->generatePermission();
			$this->generateHeaderMenuItem();
			$sql = "UPDATE wcf".WCF_N."_custompage SET permission='".$this->permission."', menuItemID=".intval($this->menuItemID)." WHERE pageID=".$this->pageID;
			WCF::getDB()->sendQuery($sql);
		}
				
		if($parentPageID == 0 && $preParentID == 0) {
			$sql = "UPDATE wcf".WCF_N."_language_item SET languageItemValue='".escapeString($name)."' WHERE languageItem LIKE 'wcf.acp.group.option.category.custompages.".$this->pageID."'";
			WCF::getDB()->sendQuery($sql);
			LanguageEditor::deleteLanguageFiles();
		}
		$this->updateTemplate($this->pageID, $content);
		$this->deletePageLocation();
		$this->generatePageLocation();
		$this->clearCaches();
	}
	
	public function importPages($pageID, $name, $description, $icon, $wrapperID=1, $content, $parentPageID, $preParentID) {

		$this->pageID = intval($pageID);
		$this->name = $name;
		$this->description = $description;
		$this->icon = $icon;
		$wrapperID = '1';
		$this->content = $content;
		$this->parentPageID = intval($parentPageID);
		$this->preParentID = intval($preParentID);
		$sql = "INSERT INTO wcf".WCF_N."_custompage (pageID, name, description, icon, wrapperID, content, parentPageID, preParentID)
						VALUES (".$pageID.", '".escapeString($name)."', '".escapeString($description)."', '".escapeString($icon)."', ".$wrapperID.", '".escapeString($content)."', 
								".$parentPageID.", ".$parentPageID.")";
								
		WCF::getDB()->sendQuery($sql);
		WCF::getCache()->addResource('custompages',
		WCF_DIR.'cache/cache.custompages.php',
		WCF_DIR.'lib/system/cache/CacheBuilderCustomPages.class.php');
		$this->generateTemplate();
		$this->generatePermission();
		if($parentPageID==0) $this->generateHeaderMenuItem();

		$sql = "UPDATE wcf".WCF_N."_custompage SET permission='".$this->permission."', menuItemID=".intval($this->menuItemID).", templateName='".$this->templateName."' WHERE pageID=".$this->pageID;
		WCF::getDB()->sendQuery($sql);
		$this->generatePageLocation();
		WCF::getCache()->clearResource('custompages', true);
		$this->clearCaches();
	}

	/**
	 * Deletes a page by pageID.
	 */
	public function deleteCustomPage($pageID) {
		//templates
		CustomPageEditor::deleteTemplate($this->pageID);
		//headerMenuItem
		CustomPageEditor::deleteHeaderMenuItem($this->pageID);
		//permissions
		CustomPageEditor::deletePermissions($this->pageID);
		//languageItems
		CustomPageEditor::deleteLanguageItems($this->pageID);
		//pageLocation
		CustomPageEditor::deletePageLocation($this->pageID);
		//database entries
        	$sql = "DELETE FROM   wcf".WCF_N."_custompage
        	WHERE   pageID = ".$this->pageID;
        	WCF::getDB()->sendQuery($sql);
        	//clear caches
		CustomPageEditor::clearCaches();
	}

	/**
	 * Deletes all existing pages.
	 */
	public function deleteAllCustomPages() {
		//get all existing pageIDs from database
		$pageIDs =array();
		$sql = "SELECT pageID FROM wcf".WCF_N."_custompage";
		$result = WCF::getDB()->sendQuery($sql);	
		while($row = WCF::getDB()->fetchArray($result)) {
			$pageIDs[] =  $row['pageID'];
		}
		//return if no page exists
		if (!count($pageIDs)) {
			return;
		}
		foreach($pageIDs as $this->pageID) {
			//templates
			CustomPageEditor::deleteTemplate($this->pageID);
			//headerMenuItem
			CustomPageEditor::deleteHeaderMenuItem($this->pageID);
			//permissions
			CustomPageEditor::deletePermissions($this->pageID);
			//languageItems
			CustomPageEditor::deleteLanguageItems($this->pageID);
			//pageLocations
			CustomPageEditor::deletePageLocation($this->pageID);
		}
		//database entries
        	$sql = "DELETE FROM   wcf".WCF_N."_custompage";
        	WCF::getDB()->sendQuery($sql);        			        
		CustomPageEditor::clearCaches();
	}

	/**
	 * generates page template.
	 */
	protected function generateTemplate() {
		$this->templateName = 'customPage-'.$this->pageID;
		$outputPath = WCF_DIR.'templates/'.$this->templateName.".tpl";
		//write template
		fwrite(fopen($outputPath, 'w'), $this->content);
	}
	
	/**
	 * updates template by ID
	 */
	protected function updateTemplate($pageID, $content) {
		$this->templateName = 'customPage-'.$this->pageID;
		$outputPath = WCF_DIR.'templates/'.$this->templateName.".tpl";
		//write template
		fwrite(fopen($outputPath, 'wb'), $this->content);
	}

	/**
	 * Deletes a single template by ID.
	 */
	protected function deleteTemplate($pageID) {
		$this->templateName = 'customPage-'.$this->pageID;
		//unlink template
		unlink(WCF_DIR.'templates/'.$this->templateName.".tpl");
	}

	/**
	 * get parentPages.
	 */
	 public function getParentPage($topPage=false) {
	 $this->pages = WCF::getCache()->get('custompages');
                if(isset($this->pages[$this->parentPageID]) && is_object($this->pages[$this->parentPageID])) {
                        $parentPage = $this->pages[$this->parentPageID];
                        if($topPage) {
                                $parentPage = $parentPage->getParentPage();
                        }
                        return $parentPage;
                }
                else return $this;
        }

	/**
	 * counts parent pages.
	 *
	 * @param	integer		$parentCount
	 */
	public function countParents($page) {
	$this->pages = WCF::getCache()->get('custompages');
		$parentCount=0;
		while(isset($page->parentPageID)) {
			$parentCount++;
			$page=$this->pages[$page->parentPageID];
		}
		return $parentCount;
	}

	/**
	 * Gets HeaderMenuItem.
	 */
	public function getHeaderMenuItem() {
		if($this->menuItemID==0) return null;
		$sql="SELECT * FROM wcf".WCF_N."_page_menu_item WHERE menuItemID=".$this->menuItemID;
		$row = WCF::getDB()->getFirstRow($sql);
		return $row;
	}

	/**
	 * Gets pages Object from Cache
	 */
	public static function getPages() {
		WCF::getCache()->addResource('custompages',
		WCF_DIR.'cache/cache.custompages.php',
		WCF_DIR.'lib/system/cache/CacheBuilderCustomPages.class.php');
		$cachedPages = WCF::getCache()->get('custompages');
		return $cachedPages;
	}

	/**
	 * gets page object from cache
	 */
	public static function getPageByID($pageID) {
		WCF::getCache()->addResource('custompages',
		WCF_DIR.'cache/cache.custompages.php',
		WCF_DIR.'lib/system/cache/CacheBuilderCustomPages.class.php');
		$pages = WCF::getCache()->get('custompages', $pageID);
		return $pages;
	}

	/**
	 * gets child pages
	 */
	public function getChildPages() {
		$sql="SELECT * FROM wcf".WCF_N."_custompage WHERE  parentPageID=".$this->pageID;
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
             	$this->childPages[] = array('pageID' => $row['pageID'], 'pageName' => $row['name'], 'icon' => $row['icon'], 'parentPageID' => $row['parentPageID']);
		}
		return $this->childPages;
	}

	/**
	 * Generates permissions
	 */
	protected function generatePermission() {
		$categoryName;
		//selects all groupIDs array  from database
		$groupIDs = array();
		$sql = "SELECT groupID FROM wcf".WCF_N."_group";
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
			$groupIDs[] =  $row['groupID'];
		}
		
		if($this->parentPageID!=0) {
			$parentTopPage = $this->getParentPage(true);
			$categoryName = str_replace("canView", "", $parentTopPage->permission).$this->pageID;
			$this->permission = $categoryName.".canView";
			$parentCategory =  str_replace(".canView", "", $parentTopPage->permission);
			$tempResult = WCF::getDB()->getFirstRow("SELECT COUNT(categoryID) AS count FROM wcf".WCF_N."_group_option_category WHERE parentCategoryName='".escapeString($parentCategory)."'");
			$showorder = $tempResult['count']+1;
			$sql="INSERT INTO wcf".WCF_N."_group_option_category (packageID, categoryName, parentCategoryName, showOrder, permissions, options)
					VALUES (".$this->packageID.", '".escapeString($categoryName)."', '".escapeString($parentCategory)."', ".$showorder.", '', '')";
			WCF::getDB()->sendQuery($sql);
			$tempResult = WCF::getDB()->getFirstRow("SELECT COUNT(optionID) AS count FROM wcf".WCF_N."_group_option WHERE categoryName='".escapeString($categoryName)."'");
			$showorder = $tempResult['count']+1;
			$sql="INSERT INTO wcf".WCF_N."_group_option (packageID, optionName, categoryName, optionType, defaultValue, showOrder)
				VALUES(".$this->packageID.", '".$this->permission."', '".$categoryName."', 'boolean', '1', ".$showorder.")";
			WCF::getDB()->sendQuery($sql);
                   	foreach ($groupIDs as $groupID) {
                   	$tempResult = WCF::getDB()->getFirstRow("SELECT optionID AS optionID FROM wcf".WCF_N."_group_option WHERE categoryName='".escapeString($categoryName)."'");
			$optionID = $tempResult['optionID'];
			$sql="INSERT INTO wcf".WCF_N."_group_option_value (groupID, optionID, optionValue)
				VALUES(".$groupID.", ".$optionID.", '1')";
			WCF::getDB()->sendQuery($sql);
			}
		}
		else {
			$categoryName = "custompages.".$this->pageID;
			$this->permission = $categoryName.".canView";
			$tempResult = WCF::getDB()->getFirstRow("SELECT COUNT(categoryID) AS count FROM wcf".WCF_N."_group_option_category WHERE parentCategoryName='custompages'");
			$showorder = $tempResult['count']+1;
			$sql="INSERT INTO wcf".WCF_N."_group_option_category (packageID, categoryName, parentCategoryName, showOrder, permissions, options)
					VALUES (".$this->packageID.", '".escapeString($categoryName)."', 'custompages',".$showorder.", '', '')";
			WCF::getDB()->sendQuery($sql);
			$tempResult = WCF::getDB()->getFirstRow("SELECT COUNT(optionID) AS count FROM wcf".WCF_N."_group_option WHERE categoryName='".escapeString($categoryName)."'");
			$showorder = $tempResult['count']+1;
			$sql="INSERT INTO wcf".WCF_N."_group_option (packageID, optionName, categoryName, optionType, defaultValue, validationPattern, enableOptions, showOrder)
				VALUES(".$this->packageID.", '".$this->permission."', '".$categoryName."', 'boolean', '1', '', '',
				".$showorder.")";
			WCF::getDB()->sendQuery($sql);
			foreach ($groupIDs as $groupID) {
                   	$tempResult = WCF::getDB()->getFirstRow("SELECT optionID AS optionID FROM wcf".WCF_N."_group_option WHERE categoryName='".escapeString($categoryName)."'");
			$optionID = $tempResult['optionID'];
			$sql="INSERT INTO wcf".WCF_N."_group_option_value (groupID, optionID, optionValue)
				VALUES(".$groupID.", ".$optionID.", '1')";
			WCF::getDB()->sendQuery($sql);
			}
		}
		//generate language Items
		$this->generateLanguageItems();
	}

	/**
	 * deletes permissions
	 */
	protected function deletePermissions() {
		//select matching optionIDs from Database
		$sql = "SELECT optionID FROM wcf".WCF_N."_group_option WHERE optionName LIKE 'custompages.".$this->pageID.".canView' OR optionName LIKE 'custompages.%.".$this->pageID.".canView'";
		$result = WCF::getDB()->sendQuery($sql);
		while($row = WCF::getDB()->fetchArray($result)) {
			$this->optionIDs[] =  $row['optionID'];
		}
		//delete optionValues
		$sql = "DELETE FROM   wcf".WCF_N."_group_option_value WHERE optionID IN (".implode(",", $this->optionIDs).")";
        	WCF::getDB()->sendQuery($sql);
        	//delete optionCategory		
        	$sql = "DELETE FROM   wcf".WCF_N."_group_option_category
        	WHERE   categoryName LIKE 'custompages.".$this->pageID."' OR categoryName LIKE 'custompages.%.".$this->pageID."'";
        	WCF::getDB()->sendQuery($sql);
        	//delete groupOption
        	$sql = "DELETE FROM   wcf".WCF_N."_group_option
        	WHERE   optionName LIKE 'custompages.".$this->pageID.".canView' OR optionName LIKE 'custompages.%.".$this->pageID.".canView'";
        	WCF::getDB()->sendQuery($sql);
	}
	
	protected static function getLanguageEditor($langID) {
		if (!count(self::$languageObjects)) {
			$languagesArray = WCF::getLanguage()->getLanguages();
			foreach ($languagesArray as $languageID => $languageName) {
				if ($languageID == WCF::getLanguage()->getLanguageID()) {
					self::$languageObjects[$languageID] = WCF::getLanguage();
					
				}
				else self::$languageObjects[$languageID] = new LanguageEditor($languageID);
			}
		}
		if (isset(self::$languageObjects[$langID])) {
			return self::$languageObjects[$langID];
		}
		else return null;
	}

	protected function generateLanguageItems() {
		//get available languages
		$languagesArray = WCF::getLanguage()->getAvailableLanguages();
		//generate items fr each language
		if($this->parentPageID!=0) $parentPage = $this->getParentPage(true);
		for ($i = 0; $i < count($languagesArray); $i++) {
			$languageItems = $languagesArray[$i];
			$language = self::getLanguageEditor($languageItems['languageID']);			
			if($this->parentPageID==0) {
				$items= array('wcf.acp.group.option.category.custompages.'.$this->pageID => $language->get($this->name),
									'wcf.acp.group.option.category.custompages.'.$this->pageID.'.description' => $language->get('wcf.acp.group.custompages.option.category.toppages.description'),
									'wcf.acp.group.option.custompages.'.$this->pageID.'.canView' => $language->get('wcf.acp.group.custompages.option.canView', array('pagename' => $this->name)),
									'wcf.acp.group.option.custompages.'.$this->pageID.'.canView.description' => $language->get('wcf.acp.group.custompages.option.canView.description', array('pagename' => $this->name)));
				if (method_exists($language, 'updateItems')) {
					$language->updateItems($items);
				}
				else {
					$language = new LanguageEditor($language->getLanguageID());					
					$language->updateItems($items);
				}
			}
			else {
				$items = array('wcf.acp.group.option.category.custompages.'.$parentPage->pageID.'.'.$this->pageID => $language->get($this->name),
									'wcf.acp.group.option.category.custompages.'.$parentPage->pageID.'.'.$this->pageID.'.description' => $language->get('wcf.acp.group.custompages.option.category.pages.description', array('pagename' => $this->name)),
									'wcf.acp.group.option.custompages.'.$parentPage->pageID.'.'.$this->pageID.'.canView' => $language->get('wcf.acp.group.custompages.option.pages.canView', array('pagename' => $this->name)),
									'wcf.acp.group.option.custompages.'.$parentPage->pageID.'.'.$this->pageID.'.canView.description' => $language->get('wcf.acp.group.custompages.option.pages.canView.description', array('pagename' => $this->name)));				
				if (method_exists($language, 'updateItems')) {
					$language->updateItems($items);
				}
				else {
					$language = new LanguageEditor($language->getLanguageID());
					$language->updateItems($items);
				}
			}
		}
	}

	/**
	 * Deletes all existing language items created by the plugin
	 */
	protected function deleteLanguageItems() {
		// delete items
        	$sql = "DELETE FROM   wcf".WCF_N."_language_item
        	WHERE   languageItem LIKE 'wcf.acp.group.option.category.custompages.".$this->pageID."' 
        	OR languageItem LIKE 'wcf.acp.group.option.category.custompages.".$this->pageID.".description' 
        	OR languageItem LIKE 'wcf.acp.group.option.custompages.".$this->pageID.".canView' 
        	OR languageItem LIKE 'wcf.acp.group.option.custompages.".$this->pageID.".canView.description' 
        	OR languageItem LIKE 'wcf.acp.group.option.category.custompages.%.".$this->pageID."' 
        	OR languageItem LIKE 'wcf.acp.group.option.category.custompages.%.".$this->pageID.".description' 
        	OR languageItem LIKE 'wcf.acp.group.option.custompages.%.".$this->pageID.".canView' 
        	OR languageItem LIKE 'wcf.acp.group.option.custompages.%.".$this->pageID.".canView.description'";
        	WCF::getDB()->sendQuery($sql);
        	//clear languages cache files
        	LanguageEditor::deleteLanguageFiles();
        }			
		
	/**
	 * generates HeaderMenuItem
	 */
	protected function generateHeaderMenuItem() {
		$menuItem = 'wcf.acp.group.option.category.custompages.'.$this->pageID;
		$menuItemLink = 'index.php?page=Custom&pageID='.$this->pageID;
		$menuItemIconS = $this->icon.'S.png';
		$menuItemIconM = $this->icon.'M.png';
		$menuShowOrder= 0;
		$menuPosition = 'header';
		$languageID = 0;
		$packID = $this->packageID;
		require_once(WCF_DIR.'lib/data/page/menu/PageMenuItemEditor.class.php');
		$this->customPageMenuItem = PageMenuItemEditor::create($menuItem, $menuItemLink, $menuItemIconS, $menuItemIconM, $menuShowOrder, $menuPosition, $languageID, $packID);

		//set permission
		$sql = "UPDATE	wcf".WCF_N."_page_menu_item
			SET permissions = 'custompages.".$this->pageID.".canView'
			WHERE menuItem = 'wcf.acp.group.option.category.custompages.".$this->pageID."'";
		WCF::getDB()->sendQuery($sql);

		PageMenuItemEditor::clearCache();
	}
	
	/**
	 * delete HeaderMenuItem
	 */
	protected function deleteHeaderMenuItem() {
        	$sql = "DELETE FROM   wcf".WCF_N."_page_menu_item
        	WHERE   menuItem LIKE 'wcf.acp.group.option.category.custompages.".$this->pageID."'";
        	WCF::getDB()->sendQuery($sql);
	}

	/**
	 * generates the page location for the "Who is Online"
	 */
	protected function generatePageLocation() {
		// creates database entries
		$locationName = 'wcf.usersOnline.location.customPage.page.'.$this->pageID;
		$locationPattern = 'index\.php\?page=Custom&.*pageID='.$this->pageID;
		$packageID = $this->packageID;
		$sql = "INSERT INTO wcf".WCF_N."_page_location (locationPattern, locationName, packageID)
				VALUES ('".escapeString($locationPattern)."', '".escapeString($locationName)."', ".$this->packageID.")";
		WCF::getDB()->sendQuery($sql);
		
		// creates language items
		$languagesArray = WCF::getLanguage()->getAvailableLanguages();
		for ($i = 0; $i < count($languagesArray); $i++) {
			$languageItems = $languagesArray[$i];
			$language = new LanguageEditor($languageItems['languageID']);
				$items= array('wcf.usersOnline.location.customPage.page.'.$this->pageID => $language->get('<a href="index.php?page=Custom&amp;pageID='.$this->pageID.'{SID_ARG_2ND}">'.$this->name.'</a>'));
				$language->updateItems($items);
		}
	}
	
	/**
	 * deletes the matching page location
	 */
	protected function deletePageLocation() {
		// location
	       	$sql = "DELETE FROM   wcf".WCF_N."_page_location
        	WHERE   locationName LIKE 'wcf.usersOnline.location.customPage.page.".$this->pageID."'";
        	WCF::getDB()->sendQuery($sql);
        	// language
        	$sql = "DELETE FROM   wcf".WCF_N."_language_item
        	WHERE   languageItem LIKE 'wcf.usersOnline.location.customPage.page.".$this->pageID."'";
        	WCF::getDB()->sendQuery($sql);
        	// clear language cache files
		LanguageEditor::deleteLanguageFiles();
        }


	/**
	 * clears all relevant caches
	 */
	protected function clearCaches() {
		// clear WCF cache
		WCF::getCache()->clear(WCF_DIR.'cache', '*.php', true);
		// update sessions
                require_once(WCF_DIR.'lib/system/session/Session.class.php');
                Session::resetSessions();	
                // delete compiled templates	
		Template::deleteCompiledTemplates();
	}
}
?>
